From anders@sushi.sanyusan.se  Sun Dec 23 15:42:40 2001
Return-Path: <anders@sushi.sanyusan.se>
Received: from sushi.sanyusan.se (h19n2fls34o835.telia.com [213.67.31.19])
	by hub.freebsd.org (Postfix) with ESMTP id 3E94737B417
	for <FreeBSD-gnats-submit@freebsd.org>; Sun, 23 Dec 2001 15:42:39 -0800 (PST)
Received: (from anders@localhost)
	by sushi.sanyusan.se (8.11.6/8.11.6) id fBNNfrD01088;
	Mon, 24 Dec 2001 00:41:53 +0100 (CET)
	(envelope-from anders)
Message-Id: <200112232341.fBNNfrD01088@sushi.sanyusan.se>
Date: Mon, 24 Dec 2001 00:41:53 +0100 (CET)
From: Anders Andersson <anders@hack.org>
Reply-To: Anders Andersson <anders@hack.org>
To: FreeBSD-gnats-submit@freebsd.org
Cc:
Subject: spelling fixes in comments
X-Send-Pr-Version: 3.113
X-GNATS-Notify:

>Number:         33131
>Category:       kern
>Synopsis:       spelling fixes in comments
>Confidential:   no
>Severity:       non-critical
>Priority:       low
>Responsible:    sheldonh
>State:          closed
>Quarter:        
>Keywords:       
>Date-Required:  
>Class:          doc-bug
>Submitter-Id:   current-users
>Arrival-Date:   Sun Dec 23 15:50:00 PST 2001
>Closed-Date:    Mon Dec 31 11:31:03 PST 2001
>Last-Modified:  Mon Dec 31 11:32:12 PST 2001
>Originator:     Anders Andersson
>Release:        FreeBSD 5.0-CURRENT i386
>Organization:
>Environment:
System: FreeBSD sushi.sanyusan.se 5.0-CURRENT FreeBSD 5.0-CURRENT #0: Sat Dec 22 19:54:47 CET 2001 toor@sushi.sanyusan.se:/usr/obj/usr/src/sys/SUSHI i386


	
>Description:
	Spelling fixes found in comments in sys/netsmb code when I was
	reading code.
	
>How-To-Repeat:
	
>Fix:

	

--- netsmb.diff begins here ---
Index: netsmb//netbios.h
===================================================================
RCS file: /home/ncvs/src/sys/netsmb/netbios.h,v
retrieving revision 1.1
diff -u -r1.1 netbios.h
--- netsmb//netbios.h	10 Apr 2001 07:59:05 -0000	1.1
+++ netsmb//netbios.h	22 Dec 2001 15:16:15 -0000
@@ -89,7 +89,7 @@
 #define	NBNS_NMFLAG_BCAST	0x01
 #define	NBNS_NMFLAG_RA		0x08	/* recursion available */
 #define	NBNS_NMFLAG_RD		0x10	/* recursion desired */
-#define	NBNS_NMFLAG_TC		0x20	/* truncation occured */
+#define	NBNS_NMFLAG_TC		0x20	/* truncation occurred */
 #define	NBNS_NMFLAG_AA		0x40	/* authoritative answer */
 
 /* 
Index: netsmb//smb.h
===================================================================
RCS file: /home/ncvs/src/sys/netsmb/smb.h,v
retrieving revision 1.2
diff -u -r1.2 smb.h
--- netsmb//smb.h	21 Aug 2001 08:21:03 -0000	1.2
+++ netsmb//smb.h	22 Dec 2001 15:19:43 -0000
@@ -33,7 +33,7 @@
  */
 
 /*
- * Common definintions and structures for SMB/CIFS protocol
+ * Common definitions and structures for SMB/CIFS protocol
  */
  
 #ifndef _NETSMB_SMB_H_
@@ -97,7 +97,7 @@
  * Security mode bits
  */
 #define SMB_SM_USER		0x01		/* server in the user security mode */
-#define	SMB_SM_ENCRYPT		0x02		/* use challenge/responce */
+#define	SMB_SM_ENCRYPT		0x02		/* use challenge/response */
 
 /*
  * NTLM capabilities
@@ -336,7 +336,7 @@
 #define ERRqfull	49	/* Print queue full */
 #define ERRqtoobig	50	/* Print queue full - no space */
 #define ERRinvpfid	52	/* Invalid print file FID */
-#define ERRsmbcmd	64	/* The server did not recognise the command */
+#define ERRsmbcmd	64	/* The server did not recognize the command */
 #define ERRsrverror	65	/* The server encountered and internal error */
 #define ERRfilespecs	67	/* The Fid and path name contains an invalid combination */
 #define ERRbadpermits	69	/* Access mode invalid */
@@ -350,7 +350,7 @@
 #define ERRtoomanyuids	90      /* Too many UIDs active on this session */
 #define ERRbaduid	91	/* The UID is not known in this session */
 #define ERRusempx	250	/* Temporarily unable to support Raw, use MPX mode */
-#define ERRusestd	251	/* Temporarily unable to support Raw, use stdandard r/w */
+#define ERRusestd	251	/* Temporarily unable to support Raw, use standard r/w */
 #define ERRcontmpx	252	/* Continue in MPX mode */
 #define ERRnosupport	65535	/* Invalid function */
 
Index: netsmb//smb_conn.h
===================================================================
RCS file: /home/ncvs/src/sys/netsmb/smb_conn.h,v
retrieving revision 1.3
diff -u -r1.3 smb_conn.h
--- netsmb//smb_conn.h	2 Dec 2001 08:47:29 -0000	1.3
+++ netsmb//smb_conn.h	22 Dec 2001 15:27:53 -0000
@@ -78,8 +78,8 @@
 #define	SMBV_WIN95		0x0010	/* used to apply bugfixes for this OS */
 #define	SMBV_PRIVATE		0x0020	/* connection can be used only by creator */
 #define	SMBV_RECONNECTING	0x0040	/* conn is in the process of reconnection */
-#define SMBV_SINGLESHARE	0x0080	/* only one share connectin should be allowed */
-#define SMBV_CREATE		0x0100	/* lookup for create opeartion */
+#define SMBV_SINGLESHARE	0x0080	/* only one share connecting should be allowed */
+#define SMBV_CREATE		0x0100	/* lookup for create operation */
 /*#define SMBV_FAILED		0x0200*/	/* last reconnect attempt has failed */
 
 
@@ -114,7 +114,7 @@
 	u_int16_t	sv_rawmode;
 	u_int32_t	sv_maxraw;	/* maximum raw-buffer size */
 	u_int32_t	sv_skey;	/* session key */
-	u_int32_t	sv_caps;	/* capabilites SMB_CAP_ */
+	u_int32_t	sv_caps;	/* capabilities SMB_CAP_ */
 };
 
 /*
Index: netsmb//smb_rq.h
===================================================================
RCS file: /home/ncvs/src/sys/netsmb/smb_rq.h,v
retrieving revision 1.1
diff -u -r1.1 smb_rq.h
--- netsmb//smb_rq.h	10 Apr 2001 07:59:06 -0000	1.1
+++ netsmb//smb_rq.h	22 Dec 2001 16:09:01 -0000
@@ -119,7 +119,7 @@
 	int		t2_flags;	/* SMBT2_ */
 	struct mbchain	t2_tparam;	/* parameters to transmit */
 	struct mbchain	t2_tdata;	/* data to transmit */
-	struct mdchain	t2_rparam;	/* received paramters */
+	struct mdchain	t2_rparam;	/* received parameters */
 	struct mdchain	t2_rdata;	/* received data */
 	struct smb_cred*t2_cred;
 	struct smb_connobj *t2_source;
Index: netsmb//smb_trantcp.c
===================================================================
RCS file: /home/ncvs/src/sys/netsmb/smb_trantcp.c,v
retrieving revision 1.4
diff -u -r1.4 smb_trantcp.c
--- netsmb//smb_trantcp.c	2 Dec 2001 08:47:29 -0000	1.4
+++ netsmb//smb_trantcp.c	22 Dec 2001 17:07:28 -0000
@@ -132,7 +132,7 @@
 		if (timevalcmp(&rtv, &atv, >=)) {
 			/*
 			 * An event of our interest may occur during locking a process.
-			 * In order to avoid missing the event that occured during locking
+			 * In order to avoid missing the event that occurred during locking
 			 * the process, test P_SELECT and rescan file descriptors if
 			 * necessary.
 			 */
--- netsmb.diff ends here ---


>Release-Note:
>Audit-Trail:
Responsible-Changed-From-To: freebsd-bugs->sheldonh 
Responsible-Changed-By: sheldonh 
Responsible-Changed-When: Thu Dec 27 06:22:00 PST 2001 
Responsible-Changed-Why:  
I'll check with Boris and then commit. 

http://www.FreeBSD.org/cgi/query-pr.cgi?pr=33131 

From: Sheldon Hearn <sheldonh@starjuice.net>
To: bp@FreeBSD.org
Cc: freebsd-gnats-submit@FreeBSD.org
Subject: kern/33131: spelling fixes for comments in smbfs kernel code
Date: Thu, 27 Dec 2001 16:25:27 +0200

 Hi Boris,
 
 Please review the patches in kern/33131 and let me know whether I can
 commit them.  They're all for kernel code, so I don't need a new smbfs
 release.
 
 Ciao,
 Sheldon.

From: Sheldon Hearn <sheldonh@starjuice.net>
To: Boris Popov <bp@freebsd.org>
Cc: freebsd-gnats-submit@FreeBSD.org
Subject: Re: kern/33131: spelling fixes for comments in smbfs kernel code 
Date: Sat, 29 Dec 2001 18:38:41 +0200

 On Sat, 29 Dec 2001 12:01:28 +0600, Boris Popov wrote:
 
 > 	I've exchanged emails with originator before an actual PR was
 > submitted and will commit it this weekend.
 
 Okay, I'll leave it to you. :-)
 
 Ciao,
 Sheldon.
State-Changed-From-To: open->closed 
State-Changed-By: bp 
State-Changed-When: Mon Dec 31 11:31:03 PST 2001 
State-Changed-Why:  
Committed. Thanks! 

http://www.FreeBSD.org/cgi/query-pr.cgi?pr=33131 
>Unformatted:

Index: netsmb//smb_rq.c
===================================================================
RCS file: /home/ncvs/src/sys/netsmb/smb_rq.c,v
retrieving revision 1.4
diff -u -r1.4 smb_rq.c
--- netsmb//smb_rq.c	9 Dec 2001 17:48:08 -0000	1.4
+++ netsmb//smb_rq.c	22 Dec 2001 16:08:13 -0000
@@ -451,8 +451,8 @@
 		return 0;
 	}
 	/*
 	 * Now we have to get all subseqent responses. The CIFS specification
 	 * says that they can be misordered which is weird.
 	 * TODO: timo
 	 */
 	totpgot = totdgot = 0;
@@ -479,7 +479,7 @@
 		    (error = md_get_uint16le(mdp, &pdisp)) != 0)
 			break;
 		if (pcount != 0 && pdisp != totpgot) {
-			SMBERROR("Can't handle misordered parameters %d:%d\n",
+			SMBERROR("Can't handle disordered parameters %d:%d\n",
 			    pdisp, totpgot);
 			error = EINVAL;
 			break;
@@ -489,7 +489,7 @@
 		    (error = md_get_uint16le(mdp, &ddisp)) != 0)
 			break;
 		if (dcount != 0 && ddisp != totdgot) {
-			SMBERROR("Can't handle misordered data\n");
+			SMBERROR("Can't handle disordered data\n");
 			error = EINVAL;
 			break;
 		}
@@ -451,8 +451,8 @@
 	}
 	/*
-	 * Now we have to get all subseqent responses. The CIFS specification
-	 * says that they can be misordered which is weird.
+	 * Now we have to get all subsequent responses. The CIFS specification
+	 * says that they can be disordered which is weird.
 	 * TODO: timo
 	 */